==> libreoffice-still-sdk-6.0.7-3-armv7h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/classes_4.js <==
var searchData=
[
  ['editpropertyhandler',['EditPropertyHandler',['../servicecom_1_1sun_1_1star_1_1form_1_1inspection_1_1EditPropertyHandler.html',1,'com::sun::star::form::inspection']]],
  ['edittime',['EditTime',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1EditTime.html',1,'com::sun::star::text::textfield::docinfo']]],
  ['elementchange',['ElementChange',['../structcom_1_1sun_1_1star_1_1util_1_1ElementChange.html',1,'com::sun::star::util']]],
  ['elementexistexception',['ElementExistException',['../exceptioncom_1_1sun_1_1star_1_1container_1_1ElementExistException.html',1,'com::sun::star::container']]],
  ['elementstackitem',['ElementStackItem',['../structcom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1ElementStackItem.html',1,'com::sun::star::xml::crypto::sax']]],
  ['ellipseshape',['EllipseShape',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EllipseShape.html',1,'com::sun::star::drawing']]],
  ['ellipticalarc',['EllipticalArc',['../structcom_1_1sun_1_1star_1_1geometry_1_1EllipticalArc.html',1,'com::sun::star::geometry']]],
  ['embeddedobjectcount',['EmbeddedObjectCount',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1EmbeddedObjectCount.html',1,'com::sun::star::text::textfield']]],
  ['embeddedobjectcreator',['EmbeddedObjectCreator',['../servicecom_1_1sun_1_1star_1_1embed_1_1EmbeddedObjectCreator.html',1,'com::sun::star::embed']]],
  ['embeddedobjectdescriptor',['EmbeddedObjectDescriptor',['../servicecom_1_1sun_1_1star_1_1embed_1_1EmbeddedObjectDescriptor.html',1,'com::sun::star::embed']]],
  ['emftools',['EmfTools',['../servicecom_1_1sun_1_1star_1_1graphic_1_1EmfTools.html',1,'com::sun::star::graphic']]],
  ['emptyundostackexception',['EmptyUndoStackException',['../exceptioncom_1_1sun_1_1star_1_1document_1_1EmptyUndoStackException.html',1,'com::sun::star::document']]],
  ['encryptionexception',['EncryptionException',['../exceptioncom_1_1sun_1_1star_1_1security_1_1EncryptionException.html',1,'com::sun::star::security']]],
  ['encryptionnotallowedexception',['EncryptionNotAllowedException',['../exceptioncom_1_1sun_1_1star_1_1packages_1_1EncryptionNotAllowedException.html',1,'com::sun::star::packages']]],
  ['enddockingevent',['EndDockingEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1EndDockingEvent.html',1,'com::sun::star::awt']]],
  ['endnote',['Endnote',['../servicecom_1_1sun_1_1star_1_1text_1_1Endnote.html',1,'com::sun::star::text']]],
  ['endnotesettings',['EndnoteSettings',['../servicecom_1_1sun_1_1star_1_1text_1_1EndnoteSettings.html',1,'com::sun::star::text']]],
  ['endpopupmodeevent',['EndPopupModeEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1EndPopupModeEvent.html',1,'com::sun::star::awt']]],
  ['engine',['Engine',['../servicecom_1_1sun_1_1star_1_1script_1_1Engine.html',1,'com::sun::star::script']]],
  ['enhancedcustomshapeadjustmentvalue',['EnhancedCustomShapeAdjustmentValue',['../structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeAdjustmentValue.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapeextrusion',['EnhancedCustomShapeExtrusion',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeExtrusion.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapegeometry',['EnhancedCustomShapeGeometry',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeGeometry.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapehandle',['EnhancedCustomShapeHandle',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeHandle.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapeparameter',['EnhancedCustomShapeParameter',['../structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameter.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapeparameterpair',['EnhancedCustomShapeParameterPair',['../structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterPair.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapepath',['EnhancedCustomShapePath',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapePath.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapesegment',['EnhancedCustomShapeSegment',['../structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegment.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapetextframe',['EnhancedCustomShapeTextFrame',['../structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeTextFrame.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapetextpath',['EnhancedCustomShapeTextPath',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeTextPath.html',1,'com::sun::star::drawing']]],
  ['enhancedmouseevent',['EnhancedMouseEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1EnhancedMouseEvent.html',1,'com::sun::star::awt']]],
  ['enumerablemap',['EnumerableMap',['../servicecom_1_1sun_1_1star_1_1container_1_1EnumerableMap.html',1,'com::sun::star::container']]],
  ['errorbar',['ErrorBar',['../servicecom_1_1sun_1_1star_1_1chart2_1_1ErrorBar.html',1,'com::sun::star::chart2']]],
  ['errorcodeioexception',['ErrorCodeIOException',['../exceptioncom_1_1sun_1_1star_1_1task_1_1ErrorCodeIOException.html',1,'com::sun::star::task']]],
  ['errorcoderequest',['ErrorCodeRequest',['../exceptioncom_1_1sun_1_1star_1_1task_1_1ErrorCodeRequest.html',1,'com::sun::star::task']]],
  ['errorevent',['ErrorEvent',['../structcom_1_1sun_1_1star_1_1form_1_1ErrorEvent.html',1,'com::sun::star::form']]],
  ['errormessagedialog',['ErrorMessageDialog',['../servicecom_1_1sun_1_1star_1_1sdb_1_1ErrorMessageDialog.html',1,'com::sun::star::sdb']]],
  ['event',['Event',['../structcom_1_1sun_1_1star_1_1animations_1_1Event.html',1,'com::sun::star::animations']]],
  ['eventdescriptor',['EventDescriptor',['../servicecom_1_1sun_1_1star_1_1document_1_1EventDescriptor.html',1,'com::sun::star::document']]],
  ['eventexception',['EventException',['../exceptioncom_1_1sun_1_1star_1_1xml_1_1dom_1_1events_1_1EventException.html',1,'com::sun::star::xml::dom::events']]],
  ['eventhandler',['EventHandler',['../servicecom_1_1sun_1_1star_1_1form_1_1inspection_1_1EventHandler.html',1,'com::sun::star::form::inspection']]],
  ['eventlistener',['EventListener',['../structcom_1_1sun_1_1star_1_1script_1_1EventListener.html',1,'com::sun::star::script']]],
  ['eventobject',['EventObject',['../structcom_1_1sun_1_1star_1_1document_1_1EventObject.html',1,'EventObject'],['../structcom_1_1sun_1_1star_1_1lang_1_1EventObject.html',1,'EventObject']]],
  ['events',['Events',['../servicecom_1_1sun_1_1star_1_1document_1_1Events.html',1,'com::sun::star::document']]],
  ['exception',['Exception',['../exceptioncom_1_1sun_1_1star_1_1uno_1_1Exception.html',1,'com::sun::star::uno']]],
  ['executabledialogexception',['ExecutableDialogException',['../exceptioncom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1ExecutableDialogException.html',1,'com::sun::star::ui::dialogs']]],
  ['expandcontentprovider',['ExpandContentProvider',['../servicecom_1_1sun_1_1star_1_1ucb_1_1ExpandContentProvider.html',1,'com::sun::star::ucb']]],
  ['expandvetoexception',['ExpandVetoException',['../exceptioncom_1_1sun_1_1star_1_1awt_1_1tree_1_1ExpandVetoException.html',1,'com::sun::star::awt::tree']]],
  ['exponentialregressioncurve',['ExponentialRegressionCurve',['../servicecom_1_1sun_1_1star_1_1chart2_1_1ExponentialRegressionCurve.html',1,'com::sun::star::chart2']]],
  ['exponentialscaling',['ExponentialScaling',['../servicecom_1_1sun_1_1star_1_1chart2_1_1ExponentialScaling.html',1,'com::sun::star::chart2']]],
  ['exportfilter',['ExportFilter',['../servicecom_1_1sun_1_1star_1_1document_1_1ExportFilter.html',1,'ExportFilter'],['../servicecom_1_1sun_1_1star_1_1xml_1_1ExportFilter.html',1,'ExportFilter']]],
  ['exportstreaminfo',['ExportStreamInfo',['../structcom_1_1sun_1_1star_1_1ucb_1_1ExportStreamInfo.html',1,'com::sun::star::ucb']]],
  ['extendedtypedetection',['ExtendedTypeDetection',['../servicecom_1_1sun_1_1star_1_1document_1_1ExtendedTypeDetection.html',1,'com::sun::star::document']]],
  ['extendedtypedetectionfactory',['ExtendedTypeDetectionFactory',['../servicecom_1_1sun_1_1star_1_1document_1_1ExtendedTypeDetectionFactory.html',1,'com::sun::star::document']]],
  ['extendeduser',['ExtendedUser',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1ExtendedUser.html',1,'com::sun::star::text::textfield']]],
  ['extensionmanager',['ExtensionManager',['../singletoncom_1_1sun_1_1star_1_1deployment_1_1ExtensionManager.html',1,'com::sun::star::deployment']]],
  ['extensionremovedexception',['ExtensionRemovedException',['../exceptioncom_1_1sun_1_1star_1_1deployment_1_1ExtensionRemovedException.html',1,'com::sun::star::deployment']]],
  ['externaldoclink',['ExternalDocLink',['../servicecom_1_1sun_1_1star_1_1sheet_1_1ExternalDocLink.html',1,'com::sun::star::sheet']]],
  ['externaldoclinks',['ExternalDocLinks',['../servicecom_1_1sun_1_1star_1_1sheet_1_1ExternalDocLinks.html',1,'com::sun::star::sheet']]],
  ['externallinkinfo',['ExternalLinkInfo',['../structcom_1_1sun_1_1star_1_1sheet_1_1ExternalLinkInfo.html',1,'com::sun::star::sheet']]],
  ['externalreference',['ExternalReference',['../structcom_1_1sun_1_1star_1_1sheet_1_1ExternalReference.html',1,'com::sun::star::sheet']]],
  ['externalsheetcache',['ExternalSheetCache',['../servicecom_1_1sun_1_1star_1_1sheet_1_1ExternalSheetCache.html',1,'com::sun::star::sheet']]],
  ['externalurireferencetranslator',['ExternalUriReferenceTranslator',['../servicecom_1_1sun_1_1star_1_1uri_1_1ExternalUriReferenceTranslator.html',1,'com::sun::star::uri']]]
];

==> libreoffice-still-sdk-6.1.6-2-armv7h.pkg.tar.xz: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/classes_4.js <==
var searchData=
[
  ['editpropertyhandler',['EditPropertyHandler',['../servicecom_1_1sun_1_1star_1_1form_1_1inspection_1_1EditPropertyHandler.html',1,'com::sun::star::form::inspection']]],
  ['edittime',['EditTime',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1docinfo_1_1EditTime.html',1,'com::sun::star::text::textfield::docinfo']]],
  ['elementchange',['ElementChange',['../structcom_1_1sun_1_1star_1_1util_1_1ElementChange.html',1,'com::sun::star::util']]],
  ['elementexistexception',['ElementExistException',['../exceptioncom_1_1sun_1_1star_1_1container_1_1ElementExistException.html',1,'com::sun::star::container']]],
  ['elementstackitem',['ElementStackItem',['../structcom_1_1sun_1_1star_1_1xml_1_1crypto_1_1sax_1_1ElementStackItem.html',1,'com::sun::star::xml::crypto::sax']]],
  ['ellipseshape',['EllipseShape',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EllipseShape.html',1,'com::sun::star::drawing']]],
  ['ellipticalarc',['EllipticalArc',['../structcom_1_1sun_1_1star_1_1geometry_1_1EllipticalArc.html',1,'com::sun::star::geometry']]],
  ['embeddedobjectcount',['EmbeddedObjectCount',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1EmbeddedObjectCount.html',1,'com::sun::star::text::textfield']]],
  ['embeddedobjectcreator',['EmbeddedObjectCreator',['../servicecom_1_1sun_1_1star_1_1embed_1_1EmbeddedObjectCreator.html',1,'com::sun::star::embed']]],
  ['embeddedobjectdescriptor',['EmbeddedObjectDescriptor',['../servicecom_1_1sun_1_1star_1_1embed_1_1EmbeddedObjectDescriptor.html',1,'com::sun::star::embed']]],
  ['emftools',['EmfTools',['../servicecom_1_1sun_1_1star_1_1graphic_1_1EmfTools.html',1,'com::sun::star::graphic']]],
  ['emptyundostackexception',['EmptyUndoStackException',['../exceptioncom_1_1sun_1_1star_1_1document_1_1EmptyUndoStackException.html',1,'com::sun::star::document']]],
  ['encryptionexception',['EncryptionException',['../exceptioncom_1_1sun_1_1star_1_1security_1_1EncryptionException.html',1,'com::sun::star::security']]],
  ['encryptionnotallowedexception',['EncryptionNotAllowedException',['../exceptioncom_1_1sun_1_1star_1_1packages_1_1EncryptionNotAllowedException.html',1,'com::sun::star::packages']]],
  ['enddockingevent',['EndDockingEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1EndDockingEvent.html',1,'com::sun::star::awt']]],
  ['endnote',['Endnote',['../servicecom_1_1sun_1_1star_1_1text_1_1Endnote.html',1,'com::sun::star::text']]],
  ['endnotesettings',['EndnoteSettings',['../servicecom_1_1sun_1_1star_1_1text_1_1EndnoteSettings.html',1,'com::sun::star::text']]],
  ['endpopupmodeevent',['EndPopupModeEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1EndPopupModeEvent.html',1,'com::sun::star::awt']]],
  ['engine',['Engine',['../servicecom_1_1sun_1_1star_1_1script_1_1Engine.html',1,'com::sun::star::script']]],
  ['enhancedcustomshapeadjustmentvalue',['EnhancedCustomShapeAdjustmentValue',['../structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeAdjustmentValue.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapeextrusion',['EnhancedCustomShapeExtrusion',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeExtrusion.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapegeometry',['EnhancedCustomShapeGeometry',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeGeometry.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapehandle',['EnhancedCustomShapeHandle',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeHandle.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapeparameter',['EnhancedCustomShapeParameter',['../structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameter.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapeparameterpair',['EnhancedCustomShapeParameterPair',['../structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeParameterPair.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapepath',['EnhancedCustomShapePath',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapePath.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapesegment',['EnhancedCustomShapeSegment',['../structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeSegment.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapetextframe',['EnhancedCustomShapeTextFrame',['../structcom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeTextFrame.html',1,'com::sun::star::drawing']]],
  ['enhancedcustomshapetextpath',['EnhancedCustomShapeTextPath',['../servicecom_1_1sun_1_1star_1_1drawing_1_1EnhancedCustomShapeTextPath.html',1,'com::sun::star::drawing']]],
  ['enhancedmouseevent',['EnhancedMouseEvent',['../structcom_1_1sun_1_1star_1_1awt_1_1EnhancedMouseEvent.html',1,'com::sun::star::awt']]],
  ['enumerablemap',['EnumerableMap',['../servicecom_1_1sun_1_1star_1_1container_1_1EnumerableMap.html',1,'com::sun::star::container']]],
  ['errorbar',['ErrorBar',['../servicecom_1_1sun_1_1star_1_1chart2_1_1ErrorBar.html',1,'com::sun::star::chart2']]],
  ['errorcodeioexception',['ErrorCodeIOException',['../exceptioncom_1_1sun_1_1star_1_1task_1_1ErrorCodeIOException.html',1,'com::sun::star::task']]],
  ['errorcoderequest',['ErrorCodeRequest',['../exceptioncom_1_1sun_1_1star_1_1task_1_1ErrorCodeRequest.html',1,'com::sun::star::task']]],
  ['errorevent',['ErrorEvent',['../structcom_1_1sun_1_1star_1_1form_1_1ErrorEvent.html',1,'com::sun::star::form']]],
  ['errormessagedialog',['ErrorMessageDialog',['../servicecom_1_1sun_1_1star_1_1sdb_1_1ErrorMessageDialog.html',1,'com::sun::star::sdb']]],
  ['event',['Event',['../structcom_1_1sun_1_1star_1_1animations_1_1Event.html',1,'com::sun::star::animations']]],
  ['eventdescriptor',['EventDescriptor',['../servicecom_1_1sun_1_1star_1_1document_1_1EventDescriptor.html',1,'com::sun::star::document']]],
  ['eventexception',['EventException',['../exceptioncom_1_1sun_1_1star_1_1xml_1_1dom_1_1events_1_1EventException.html',1,'com::sun::star::xml::dom::events']]],
  ['eventhandler',['EventHandler',['../servicecom_1_1sun_1_1star_1_1form_1_1inspection_1_1EventHandler.html',1,'com::sun::star::form::inspection']]],
  ['eventlistener',['EventListener',['../structcom_1_1sun_1_1star_1_1script_1_1EventListener.html',1,'com::sun::star::script']]],
  ['eventobject',['EventObject',['../structcom_1_1sun_1_1star_1_1document_1_1EventObject.html',1,'EventObject'],['../structcom_1_1sun_1_1star_1_1lang_1_1EventObject.html',1,'EventObject']]],
  ['events',['Events',['../servicecom_1_1sun_1_1star_1_1document_1_1Events.html',1,'com::sun::star::document']]],
  ['exception',['Exception',['../exceptioncom_1_1sun_1_1star_1_1uno_1_1Exception.html',1,'com::sun::star::uno']]],
  ['executabledialogexception',['ExecutableDialogException',['../exceptioncom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1ExecutableDialogException.html',1,'com::sun::star::ui::dialogs']]],
  ['exoticfileloadexception',['ExoticFileLoadException',['../exceptioncom_1_1sun_1_1star_1_1document_1_1ExoticFileLoadException.html',1,'com::sun::star::document']]],
  ['expandcontentprovider',['ExpandContentProvider',['../servicecom_1_1sun_1_1star_1_1ucb_1_1ExpandContentProvider.html',1,'com::sun::star::ucb']]],
  ['expandvetoexception',['ExpandVetoException',['../exceptioncom_1_1sun_1_1star_1_1awt_1_1tree_1_1ExpandVetoException.html',1,'com::sun::star::awt::tree']]],
  ['exponentialregressioncurve',['ExponentialRegressionCurve',['../servicecom_1_1sun_1_1star_1_1chart2_1_1ExponentialRegressionCurve.html',1,'com::sun::star::chart2']]],
  ['exponentialscaling',['ExponentialScaling',['../servicecom_1_1sun_1_1star_1_1chart2_1_1ExponentialScaling.html',1,'com::sun::star::chart2']]],
  ['exportfilter',['ExportFilter',['../servicecom_1_1sun_1_1star_1_1document_1_1ExportFilter.html',1,'ExportFilter'],['../servicecom_1_1sun_1_1star_1_1xml_1_1ExportFilter.html',1,'ExportFilter']]],
  ['exportstreaminfo',['ExportStreamInfo',['../structcom_1_1sun_1_1star_1_1ucb_1_1ExportStreamInfo.html',1,'com::sun::star::ucb']]],
  ['extendedtypedetection',['ExtendedTypeDetection',['../servicecom_1_1sun_1_1star_1_1document_1_1ExtendedTypeDetection.html',1,'com::sun::star::document']]],
  ['extendedtypedetectionfactory',['ExtendedTypeDetectionFactory',['../servicecom_1_1sun_1_1star_1_1document_1_1ExtendedTypeDetectionFactory.html',1,'com::sun::star::document']]],
  ['extendeduser',['ExtendedUser',['../servicecom_1_1sun_1_1star_1_1text_1_1textfield_1_1ExtendedUser.html',1,'com::sun::star::text::textfield']]],
  ['extensionmanager',['ExtensionManager',['../singletoncom_1_1sun_1_1star_1_1deployment_1_1ExtensionManager.html',1,'com::sun::star::deployment']]],
  ['extensionremovedexception',['ExtensionRemovedException',['../exceptioncom_1_1sun_1_1star_1_1deployment_1_1ExtensionRemovedException.html',1,'com::sun::star::deployment']]],
  ['externaldoclink',['ExternalDocLink',['../servicecom_1_1sun_1_1star_1_1sheet_1_1ExternalDocLink.html',1,'com::sun::star::sheet']]],
  ['externaldoclinks',['ExternalDocLinks',['../servicecom_1_1sun_1_1star_1_1sheet_1_1ExternalDocLinks.html',1,'com::sun::star::sheet']]],
  ['externallinkinfo',['ExternalLinkInfo',['../structcom_1_1sun_1_1star_1_1sheet_1_1ExternalLinkInfo.html',1,'com::sun::star::sheet']]],
  ['externalreference',['ExternalReference',['../structcom_1_1sun_1_1star_1_1sheet_1_1ExternalReference.html',1,'com::sun::star::sheet']]],
  ['externalsheetcache',['ExternalSheetCache',['../servicecom_1_1sun_1_1star_1_1sheet_1_1ExternalSheetCache.html',1,'com::sun::star::sheet']]],
  ['externalurireferencetranslator',['ExternalUriReferenceTranslator',['../servicecom_1_1sun_1_1star_1_1uri_1_1ExternalUriReferenceTranslator.html',1,'com::sun::star::uri']]]
];
